@@ -623,12 +623,12 @@ func IsNeedQuoted(value string) bool {
 	}
 	first := value[0]
 	switch first {
-	case '*', '&', '[', '{', '}', ']', ',', '!', '|', '>', '%', '\'', '"', '@':
+	case '*', '&', '[', '{', '}', ']', ',', '!', '|', '>', '%', '\'', '"', '@', ' ':
 		return true
 	}
 	last := value[len(value)-1]
 	switch last {
-	case ':':
+	case ':', ' ':
 		return true
 	}
 	if looksLikeTimeValue(value) {
